@@ -115,7 +115,11 @@ class Deserialize:
                     output[map_def.key] = map_def.map(value)
                 return output
 
-            return {k: v(data.get(k)) for (k, v) in map_defs.items()}
+            # In case non-dict data gets here, just bail out
+            try:
+                return {k: v(data.get(k)) for (k, v) in map_defs.items()}
+            except AttributeError:
+                return {}
 
         return mapper
 
