@@ -11,11 +11,12 @@ from .validation_result import ValidationResult
 
 Record = Mapping[str, Any]
 MutableRecord = MutableMapping[str, Any]
-ValidateFieldSync = Callable[[Any], bool]
-ValidateFieldAsync = Callable[[Any], Awaitable[bool]]
+ValidatorResult = Union[bool, str, None]
+ValidateFieldSync = Callable[[Any], ValidatorResult]
+ValidateFieldAsync = Callable[[Any], Awaitable[ValidatorResult]]
 ValidateField = Union[ValidateFieldSync, ValidateFieldAsync]
-ValidateRecordSync = Callable[[Record], bool]
-ValidateRecordAsync = Callable[[Record], Awaitable[bool]]
+ValidateRecordSync = Callable[[Record], ValidatorResult]
+ValidateRecordAsync = Callable[[Record], Awaitable[ValidatorResult]]
 ValidateRecord = Union[ValidateRecordSync, ValidateRecordAsync]
 
 NUMBER_TYPES = (int, float, Decimal)
@@ -27,11 +28,11 @@ class FieldValidator:
     """Information to validate a single field."""
 
     prop_name: str
-    message: str
+    message: Union[str, None]
     validator: ValidateField
     field_name: Optional[str] = None
 
-    async def validate(self, value: Any) -> bool:
+    async def validate(self, value: Any) -> ValidatorResult:
         """Properly calls the validator."""
         if inspect.iscoroutinefunction(self.validator):
             return await cast(ValidateFieldAsync, self.validator)(value)
@@ -46,12 +47,12 @@ class FieldValidator:
 class RecordValidator:
     """Information to validate a whole record."""
 
-    message: str
+    message: Union[str, None]
     validator: ValidateRecord
     output_name: Optional[str]
     dependencies: Optional[Iterable[str]] = None
 
-    async def validate(self, record: Record) -> bool:
+    async def validate(self, record: Record) -> ValidatorResult:
         """Properly calls the validator."""
         if inspect.iscoroutinefunction(self.validator):
             return await cast(ValidateRecordAsync, self.validator)(record)
@@ -70,7 +71,7 @@ class Validator:
     @staticmethod
     def field(
         prop_name: str,
-        message: str,
+        message: Union[str, None],
         validate: ValidateField,
         field_name: Optional[str] = None,
     ) -> FieldValidator:
@@ -79,11 +80,12 @@ class Validator:
 
     @staticmethod
     def record(
-        message: str,
+        message: Union[str, None],
         validate: ValidateRecord,
         output_name: str = None,
         dependencies: Optional[Iterable[str]] = None,
     ) -> RecordValidator:
+        """Helper to create a RecordValidator."""
         return RecordValidator(message, validate, output_name, dependencies)
 
     async def validate(
@@ -147,20 +149,30 @@ class ValidatorInstance:
         value = self.record.get(validator.prop_name, None)
         result = await validator.validate(value)
 
-        if not result:
-            self.validation_result.add_message(validator.output_name, validator.message)
+        if result is False:
+            message = validator.message or "is invalid"
+        elif isinstance(result, str):
+            message = result or validator.message or "is invalid"
+        else:
+            return
+
+        self.validation_result.add_message(validator.output_name, message)
 
     async def validate_record(self, validator: RecordValidator) -> None:
         """Validate an entire record."""
         result = await validator.validate(self.record)
 
-        if not result:
-            if validator.output_name:
-                self.validation_result.add_message(
-                    validator.output_name, validator.message
-                )
-            else:
-                self.validation_result.add_general_message(validator.message)
+        if result is False:
+            message = validator.message or "is invalid"
+        elif isinstance(result, str):
+            message = result or "is invalid"
+        else:
+            return
+
+        if validator.output_name:
+            self.validation_result.add_message(validator.output_name, message)
+        else:
+            self.validation_result.add_general_message(message)
 
 
 class Validators:
@@ -257,6 +269,15 @@ class Validators:
 
         return checker
 
+    @staticmethod
+    def is_list_type(typ: Union[Type, tuple[Type]]) -> ValidateFieldSync:
+        """Validates that a value is a list and each member is a type."""
+
+        def checker(val: Any) -> bool:
+            return isinstance(val, list) and all(isinstance(item, typ) for item in val)
+
+        return checker
+
     @staticmethod
     def is_member(members: Union[Sequence, Set]) -> ValidateFieldSync:
         """Validates that a value is a member of a sequence."""
